@@ -6,8 +6,9 @@ use strict;
 use warnings 'all';
 
 package BZ::Client;
-$BZ::Client::VERSION = '2.0_9';
-use BZ::Client::XMLRPC;
+$BZ::Client::VERSION = '2.0_11'; # TRIAL
+
+$BZ::Client::VERSION = '2.011';use BZ::Client::XMLRPC;
 use BZ::Client::Exception;
 use HTTP::CookieJar;
 
@@ -204,7 +205,9 @@ sub is_logged_in {
 
 sub api_call {
     my ( $self, $methodName, $params ) = @_;
+
     $params ||= {};
+
     if ( $self->autologin && not $self->is_logged_in() ) {
         $self->login();
     }
@@ -267,7 +270,7 @@ BZ::Client - A client for the Bugzilla web services API.
 
 =head1 VERSION
 
-version 2.0_9
+version 2.0_11
 
 =head1 SYNOPSIS
 
