@@ -6,8 +6,9 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Bug;
-$BZ::Client::Bug::VERSION = '2.0_9';
-use parent qw( BZ::Client::API );
+$BZ::Client::Bug::VERSION = '2.0_11'; # TRIAL
+
+$BZ::Client::Bug::VERSION = '2.011';use parent qw( BZ::Client::API );
 
 # See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Bug.html
 # These are in order as per the above
@@ -16,123 +17,87 @@ use parent qw( BZ::Client::API );
 
 sub fields {
     my($class, $client, $params) = @_;
-    $client->log('debug', __PACKAGE__ . '::fields: Retrieving');
-    my $result = $class->api_call($client, 'Bug.fields', $params);
-    my $fields = $result->{'fields'};
-    if (!$fields || 'ARRAY' ne ref($fields)) {
-        $class->error($client, 'Invalid reply by server, expected array of fields.');
-    }
-    $client->log('debug', __PACKAGE__ . '::fields: Got ' . scalar @$fields);
-    return wantarray ? @$fields : $fields
+    return $class->_returns_array($client, 'Bug.fields', $params, 'fields');
 }
 
 sub legal_values {
     my($class, $client, $field) = @_;
-    $client->log('debug', __PACKAGE__ . "::legal_values: Asking for $field");
     my $params = { 'field' => $field };
-    my $result = $class->api_call($client, 'Bug.legal_values', $params);
-    my $values = $result->{'values'};
-    if (!$values || 'ARRAY' ne ref($values)) {
-        $class->error($client, 'Invalid reply by server, expected array of values.');
-    }
-    $client->log('debug', __PACKAGE__ . '::legal_values: Got ' . join(',', @$values));
-    return wantarray ? @$values : $values
+    return $class->_returns_array($client, 'Bug.legal_values', $params, 'values');
 }
 
 sub get {
     my($class, $client, $params) = @_;
-    $client->log('debug', __PACKAGE__ . '::get: Asking');
     $params->{'permissive'} = BZ::Client::XMLRPC::boolean::TRUE()
         if $params->{'permissive'};
-    my $result = $class->api_call($client, 'Bug.get', $params);
-    my $bugs = $result->{'bugs'};
-    if (!$bugs  ||  'ARRAY' ne ref($bugs)) {
-        $class->error($client, 'Invalid reply by server, expected array of bugs.');
-    }
+    my $bugs = $class->_returns_array($client, 'Bug.get', $params, 'bugs');
     my @result;
     for my $bug (@$bugs) {
-        push(@result, BZ::Client::Bug->new(%$bug));
+        push(@result, $class->new(%$bug));
     }
-    $client->log('debug', __PACKAGE__ . '::get: Got ' . scalar(@result));
+    $client->log('debug', $class . '::get: Got ' . scalar(@result));
     return wantarray ? @result : \@result
 }
 
 sub history {
     my($class, $client, $params) = @_;
-    $client->log('debug', __PACKAGE__ . '::history: Retrieving');
-    my $result = $class->api_call($client, 'Bug.history', $params);
-    my $bugs = $result->{'bugs'};
-    if (!$bugs || 'ARRAY' ne ref($bugs)) {
-        $class->error($client, 'Invalid reply by server, expected array of bug changes.');
-    }
-    $client->log('debug', __PACKAGE__ . '::history: Got ' . scalar @$bugs);
-    return wantarray ? @$bugs : $bugs
+    return $class->_returns_array($client, 'Bug.history', $params, 'bugs');
 }
 
 sub possible_duplicates {
     my($class, $client, $params) = @_;
-    $client->log('debug', __PACKAGE__ . '::possible_duplicates: Asking');
-    my $result = $class->api_call($client, 'Bug.possible_duplicates', $params);
-    my $bugs = $result->{'bugs'};
-    if (!$bugs  ||  'ARRAY' ne ref($bugs)) {
-        $class->error($client, 'Invalid reply by server, expected array of bugs.');
-    }
+    my $bugs = $class->_returns_array($client, 'Bug.possible_duplicates', $params, 'bugs');
     my @result;
     for my $bug (@$bugs) {
-        push(@result, __PACKAGE__->new(%$bug));
+        push(@result, $class->new(%$bug));
     }
-    $client->log('debug', __PACKAGE__ . '::possible_duplicates: Got ' . scalar(@result));
+    $client->log('debug', $class . '::possible_duplicates: Got ' . scalar(@result));
     return wantarray ? @result : \@result
 }
 
 sub search {
     my($class, $client, $params) = @_;
-    $client->log('debug', __PACKAGE__ . '::search: Searching');
-    my $result = $class->api_call($client, 'Bug.search', $params);
-    my $bugs = $result->{'bugs'};
-    if (!$bugs || 'ARRAY' ne ref($bugs)) {
-        $class->error($client, 'Invalid reply by server, expected array of bugs.');
-    }
+    my $bugs = $class->_returns_array($client, 'Bug.search', $params, 'bugs');
     my @result;
     for my $bug (@$bugs) {
-        push(@result, __PACKAGE__->new(%$bug));
+        push(@result, $class->new(%$bug));
     }
-    $client->log('debug', __PACKAGE__ . '::search: Found ' . join(',',@result));
+    $client->log('debug', $class . '::search: Found ' . join(',',@result));
     return wantarray ? @result : \@result
 }
 
 sub create {
     my($class, $client, $params) = @_;
-    return _create($client, 'Bug.create', $params);
+    return $class->_create($client, 'Bug.create', $params);
 }
 
 sub update {
     my($class, $client, $params) = @_;
-    return _returns_array($client, 'Bug.update', $params, 'bugs');
+    return $class->_returns_array($client, 'Bug.update', $params, 'bugs');
 
 }
 
 sub update_see_also {
     my($class, $client, $params) = @_;
-    $client->log('debug', __PACKAGE__ . '::update_see_also: Updating See-Also');
+    $client->log('debug', $class . '::update_see_also: Updating See-Also');
     my $result = $class->api_call($client, 'Bug.update_see_also', $params);
     my $changes = $result->{'changes'};
     if (!$changes || 'HASH' ne ref($changes)) {
         $class->error($client, 'Invalid reply by server, expected hash of changed bug details.');
     }
-    $client->log('debug', __PACKAGE__ . '::update_see_also: Updated stuff');
+    $client->log('debug', $class . '::update_see_also: Updated stuff');
     return wantarray ? %$changes : $changes
 }
 
 sub update_tags {
     my($class, $client, $params) = @_;
-    $client->log('debug', __PACKAGE__ . '::update_tags: Updating Tags');
+    $client->log('debug', $class . '::update_tags: Updating Tags');
     my $result = $class->api_call($client, 'Bug.update_tags', $params);
     my $changes = $result->{'changes'};
     if (!$changes || 'HASH' ne ref($changes)) {
         $class->error($client, 'Invalid reply by server, expected hash of changed bug details.');
     }
-    $client->log('debug', __PACKAGE__ . '::update_tags: Updated stuff');
+    $client->log('debug', $class . '::update_tags: Updated stuff');
     return wantarray ? %$changes : $changes
 }
 
@@ -322,7 +287,7 @@ BZ::Client::Bug - Client side representation of a bug in Bugzilla
 
 =head1 VERSION
 
-version 2.0_9
+version 2.0_11
 
 =head1 SYNOPSIS
 
@@ -336,16 +301,18 @@ This class provides methods for accessing and managing bugs in Bugzilla.
 
 =head1 COMMON PARAMETERS
 
-Many Webservice methods take similar arguments. Instead of re-writing the documentation for each method, we document the parameters here, once, and then refer back to this documentation from the individual methods where these parameters are used.
+Many Bugzilla Webservice methods take similar arguments. Instead of re-writing the documentation for each method, we document the parameters here, once, and then refer back to this documentation from the individual methods where these parameters are used.
 
 =head2 Limiting What Fields Are Returned
 
 Many methods return an array of structs with various fields in the structs.
-(For example, L<get> in L<BZ::Client::Bug> returns a list of bugs that have fields like
-L<id>, L<summary>, L<creation_time>, etc.)
+(For example, L</get> in L<BZ::Client::Bug> returns a list of bugs that have fields like
+L</id>, L</summary>, L</creation_time>, etc.)
 
 These parameters allow you to limit what fields are present in the structs, to possibly improve performance or save some bandwidth.
 
+Fields follow:
+
 =head3 include_fields
 
 I<include_fields> (array) - An array of strings, representing the (case-sensitive) names of fields in the return value. Only the fields specified in this hash will be returned, the rest will not be included.
@@ -373,7 +340,7 @@ Some RPC calls support specifying sub fields. If an RPC call states that it supp
 
 Invalid field names are ignored.
 
-Specifying fields here overrides L<include_fields>, so if you specify a field in both, it will be excluded, not included.
+Specifying fields here overrides L</include_fields>, so if you specify a field in both, it will be excluded, not included.
 
 Example:
 
@@ -392,19 +359,19 @@ There are several shortcut identifiers to ask for only certain groups of fields
 
 =item _all
 
-All possible fields are returned if _all is specified in include_fields.
+All possible fields are returned if C<_all> is specified in L</include_fields>.
 
 =item _default
 
-These fields are returned if include_fields is empty or _default is specified. All fields described in the documentation are returned by default unless specified otherwise.
+These fields are returned if L</include_fields> is empty or C<_default> is specified. All fields described in the documentation are returned by default unless specified otherwise.
 
 =item _extra
 
-These fields are not returned by default and need to be manually specified in include_fields either by field name, or using _extra.
+These fields are not returned by default and need to be manually specified in L</include_fields> either by field name, or using C<_extra>.
 
 =item _custom
 
-Only custom fields are returned if _custom is specified in include_fields. This is normally specific to bug objects and not relevant for other returned objects.
+Only custom fields are returned if C<_custom> is specified in L</include_fields>. This is normally specific to bug objects and not relevant for other returned objects.
 
 =back
 
@@ -426,6 +393,8 @@ These deal with bug-related information, but not bugs directly.
 
 Get information about valid bug fields, including the lists of legal values for each field.
 
+=head3 History
+
 Added in Bugzilla 3.6
 
 =head3 Parameters
@@ -446,7 +415,7 @@ I<names> (array) - An array of strings representing field names.
 
 =back
 
-In addition to the parameters above, this method also accepts the standard I<include_fields> and I<exclude_fields> arguments.
+In addition to the parameters above, this method also accepts the standard L</include_fields> and L</exclude_fields> arguments.
 
 =head3 Returns
 
@@ -506,7 +475,7 @@ I<is_on_bug_entry> (boolean) For custom fields, this is true if the field is sho
 
 =item visibility_field
 
-I<visibility_field> (string) The name of a field that controls the visibility of this field in the user interface. This field only appears in the user interface when the named field is equal to one of the values in visibility_values. Can be null.
+I<visibility_field> (string) The name of a field that controls the visibility of this field in the user interface. This field only appears in the user interface when the named field is equal to one of the values in L</visibility_values>. Can be null.
 
 =item visibility_values
 
@@ -518,7 +487,7 @@ I<value_field> (string) The name of the field that controls whether or not parti
 
 =item values
 
-This is an array of hashes, representing the legal values for select-type (drop-down and multiple-selection) fields. This is also populated for the component, version, target_milestone, and keywords fields, but not for the product field (you must use L<BZ::Client::Product/get_accessible_products> for that).
+This is an array of hashes, representing the legal values for select-type (drop-down and multiple-selection) fields. This is also populated for the L</component>, L</version>, L</target_milestone>, and L</keywords> fields, but not for the C<product> field (you must use L<BZ::Client::Product/get_accessible_products> for that).
 
 For fields that aren't select-type fields, this will simply be an empty array.
 
@@ -528,7 +497,7 @@ Each hash has the following keys:
 
 =item name
 
-I<name> (string) The actual value--this is what you would specify for this field in "create", etc.
+I<name> (string) The actual value--this is what you would specify for this field in L</create>, etc.
 
 =item sort_key
 
@@ -536,7 +505,7 @@ I<sort_key> (int) Values, when displayed in a list, are sorted first by this int
 
 =item sortkey
 
-DEPRECATED - Use I<sort_key> instead.
+DEPRECATED - Use L</sort_key> instead.
 
 Renamed to sort_key in Bugzilla 4.2.
 
@@ -544,11 +513,11 @@ Renamed to sort_key in Bugzilla 4.2.
 
 If L</value_field> is defined for this field, then this value is only shown if the L</value_field> is set to one of the values listed in this array.
 
-Note that for per-product fields, L</value_field> is set to 'product' and L</visibility_values> will reflect which product(s) this value appears in.
+Note that for per-product fields, L</value_field> is set to C<product> and L</visibility_values> will reflect which product(s) this value appears in.
 
 =item is_active
 
-I<is_active> (boolean) This value is defined only for certain product specific fields such as version, target_milestone or component.
+I<is_active> (boolean) This value is defined only for certain product specific fields such as L</version>, L</target_milestone> or L</component>.
 
 When true, the value is active, otherwise the value is not active.
 
@@ -556,7 +525,7 @@ Added in Bugzilla 4.4.
 
 =item description
 
-I<description> (string) The description of the value. This item is only included for the keywords field.
+I<description> (string) The description of the value. This item is only included for the L</keywords> field.
 
 =item is_open
 
@@ -662,13 +631,13 @@ Gets information about particular bugs in the database.
 
 An array of numbers and strings.
 
-If an element in the array is entirely numeric, it represents a bug_id from the Bugzilla database to fetch. If it contains any non-numeric characters, it is considered to be a bug alias instead, and the bug with that alias will be loaded.
+If an element in the array is entirely numeric, it represents a C<bug_id> from the Bugzilla database to fetch. If it contains any non-numeric characters, it is considered to be a bug alias instead, and the bug with that alias will be loaded.
 
 =item permissive
 
 I<permissive> (boolean) Normally, if you request any inaccessible or invalid bug ids, will throw an error.
 
-If this parameter is True, instead of throwing an error we return an array of hashes with a I<id>, I<faultString> and I<faultCode> for each bug that fails, and return normal information for the other bugs that were accessible.
+If this parameter is True, instead of throwing an error we return an array of hashes with a C<id>, C<faultString> and C<faultCode> for each bug that fails, and return normal information for the other bugs that were accessible.
 
 Note: marked as B<EXPERIMENTAL> in Bugzilla 4.4
 
@@ -732,7 +701,7 @@ Added in Bugzilla 3.4.
 
 An array of numbers and strings.
 
-If an element in the array is entirely numeric, it represents a bug_id from the Bugzilla database to fetch. If it contains any non-numeric characters, it is considered to be a bug alias instead, and the data bug with that alias will be loaded.
+If an element in the array is entirely numeric, it represents a C<bug_id> from the Bugzilla database to fetch. If it contains any non-numeric characters, it is considered to be a bug alias instead, and the data bug with that alias will be loaded.
 
 =back
 
@@ -758,7 +727,7 @@ An array of hashes, each hash having the following keys:
 
 =item when
 
-I<when> (dateTime) The date the bug activity/change happened.
+I<when> (L<DateTime>) The date the bug activity/change happened.
 
 =item who
 
@@ -784,7 +753,7 @@ I<added> (string) The new value of the bug field which has been added by the cha
 
 =item attachment_id
 
-I<attachment_id> (int) The id of the attachment that was changed. This only appears if the change was to an attachment, otherwise attachment_id will not be present in this hash.
+I<attachment_id> (int) The id of the attachment that was changed. This only appears if the change was to an attachment, otherwise L</attachment_id> will not be present in this hash.
 
 =back
 
@@ -794,7 +763,21 @@ I<attachment_id> (int) The id of the attachment that was changed. This only appe
 
 =head3 Errors
 
-The same as L</get>.
+=over 4
+
+=item 100 - Invalid Bug Alias
+
+If you specified an alias and there is no bug with that alias.
+
+=item 101 - Invalid Bug ID
+
+The bug_id you specified doesn't exist in the database.
+
+=item 102 - Access Denied
+
+You do not have access to the bug_id you specified.
+
+=back
 
 =head2 possible_duplicates
 
@@ -803,6 +786,8 @@ The same as L</get>.
 
 Allows a user to find possible duplicate bugs based on a set of keywords such as a user may use as a bug summary. Optionally the search can be narrowed down to specific products.
 
+=head3 History
+
 Added in Bugzilla 4.0.
 
 =head3 Parameters
@@ -831,7 +816,7 @@ Note that you will only be returned information about bugs that you can see. Bug
 
 =item 50 - Param Required
 
-You must specify a value for I<summary> containing a string of keywords to search for duplicates.
+You must specify a value for L</summary> containing a string of keywords to search for duplicates.
 
 =back
 
@@ -847,6 +832,8 @@ Listed here in order of what you most likely want to do... maybe?
 
 Creates a new bug in your Bugzilla server and returns the bug ID.
 
+FIXME more details needed
+
 =head2 update
 
   my $id = BZ::Client::Bug->update( $client, \%params );
@@ -864,6 +851,8 @@ FIXME more details needed
 
 Adds or removes URLs for the I<See Also> field on bugs. These URLs must point to some valid bug in some Bugzilla installation or in Launchpad.
 
+=head3 History
+
 This is marked as B<EXPERIMENTAL> in Bugzilla 4.4
 
 Added in Bugzilla 3.4.
@@ -892,13 +881,13 @@ If you specify a URL that is not in the I<See Also> field of a particular bug, i
 
 =back
 
-NOTE: If you specify the same URL in both I<add> and I<remove>, it will be added. (That is, I<add> overrides I<remove>.)
+NOTE: If you specify the same URL in both L</add> and L</remove>, it will be added. (That is, L</add> overrides L</remove>.)
 
 =head3 Returns
 
-A hash or hashref where the keys are numeric bug ids and the contents are a hash with one key, I<see_also>.
+A hash or hashref where the keys are numeric bug ids and the contents are a hash with one key, C<see_also>.
 
-I<see_also> points to a hash, which contains two keys, I<added> and I<removed>.
+C<see_also> points to a hash, which contains two keys, C<added> and C<removed>.
 
 These are arrays of strings, representing the actual changes that were made to the bug.
 
@@ -921,14 +910,24 @@ Here's a diagram of what the return value looks like for updating bug ids 1 and
 
 This return value allows you to tell what this method actually did.
 
-It is in this format to be compatible with the return value of a future L<\update> method.
+It is in this format to be compatible with the return value of a future L</update> method.
 
 =head3 Errors
 
-This method can throw all of the errors that L</get> throws, plus:
-
 =over 4
 
+=item 100 - Invalid Bug Alias
+
+If you specified an alias and there is no bug with that alias.
+
+=item 101 - Invalid Bug ID
+
+The bug_id you specified doesn't exist in the database.
+
+=item 102 - Access Denied
+
+You do not have access to the bug_id you specified.
+
 =item 109 - Bug Edit Denied
 
 You did not have the necessary rights to edit the bug.
@@ -952,6 +951,8 @@ Before Bugzilla 3.6, error 115 had a generic error code of 32000.
 
 Adds or removes tags on bugs.
 
+=head3 History
+
 This is marked as B<UNSTABLE> in Bugzilla 4.4
 
 Added in Bugzilla 4.4.
@@ -988,9 +989,9 @@ It is safe to specify tags that are not associated with any bugs as they will ju
 
 =head3 Returns
 
-A hash or hashref where the keys are numeric bug ids and the contents are a hash with one key, I<tags>.
+A hash or hashref where the keys are numeric bug ids and the contents are a hash with one key, C<tags>.
 
-I<tags> points to a hash, which contains two keys, I<added> and I<removed>.
+C<tags> points to a hash, which contains two keys, C<added> and C<removed>.
 
 These are arrays of strings, representing the actual changes that were made to the bug.
 
@@ -1015,7 +1016,21 @@ This return value allows you to tell what this method actually did.
 
 =head3 Errors
 
-This method can throw all of the errors that L</get> throws.
+=over 4
+
+=item 100 - Invalid Bug Alias
+
+If you specified an alias and there is no bug with that alias.
+
+=item 101 - Invalid Bug ID
+
+The bug_id you specified doesn't exist in the database.
+
+=item 102 - Access Denied
+
+You do not have access to the bug_id you specified.
+
+=back
 
 =head2 new
 
@@ -1025,7 +1040,7 @@ Creates a new bug object instance with the given ID.
 
 B<Note:> Doesn't actually touch your bugzilla server.
 
-See L<INSTANCE METHODS> for how to use it.
+See L</INSTANCE METHODS> for how to use it.
 
 =head1 INSTANCE METHODS
 
