@@ -6,16 +6,17 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Bugzilla;
-$BZ::Client::Bugzilla::VERSION = '2.0_9';
-use parent qw( BZ::Client::API );
+$BZ::Client::Bugzilla::VERSION = '2.0_11'; # TRIAL
+
+$BZ::Client::Bugzilla::VERSION = '2.011';use parent qw( BZ::Client::API );
 
 ## functions
 
 sub extensions {
     my($class, $client) = @_;
-    $client->log('debug', __PACKAGE__ . '::extensions: Asking');
+    $client->log('debug', $class . '::extensions: Asking');
     my $result = $class->api_call($client, 'Bugzilla.extensions');
-    $client->log('debug', __PACKAGE__ . '::extensions: Got stuff');
+    $client->log('debug', $class . '::extensions: Got stuff');
     my $extensions = $result->{'extensions'};
     if (!$extensions || 'HASH' ne ref($extensions)) {
         $class->error($client, 'Invalid reply by server, expected hash of extensions.');
@@ -25,59 +26,59 @@ sub extensions {
 
 sub parameters {
     my($class, $client) = @_;
-    $client->log('debug', __PACKAGE__ . '::parameters: Asking');
+    $client->log('debug', $class . '::parameters: Asking');
     my $result = $class->api_call($client, 'Bugzilla.parameters');
-    $client->log('debug', __PACKAGE__ . '::parameters: Got stuff');
+    $client->log('debug', $class . '::parameters: Got stuff');
     my $parameters = $result->{'parameters'};
     if (!$parameters || 'HASH' ne ref($parameters)) {
         $class->error($client, 'Invalid reply by server, expected hash of parameters.');
     }
-    $client->log('debug', __PACKAGE__ . '::parameters: Got ' . scalar %$parameters);
+    $client->log('debug', $class . '::parameters: Got ' . scalar %$parameters);
     return wantarray ? %$parameters : $parameters
 }
 
 sub last_audit_time {
     my($class, $client, $params) = @_;
-    $client->log('debug', __PACKAGE__ . '::last_audit_time: Asking');
+    $client->log('debug', $class . '::last_audit_time: Asking');
     my $result = $class->api_call($client, 'Bugzilla.last_audit_time', $params);
-    $client->log('debug', __PACKAGE__ . '::last_audit_time: Got stuff');
+    $client->log('debug', $class . '::last_audit_time: Got stuff');
     my $last_audit_time = $result->{'last_audit_time'};
     if (!$last_audit_time || ! ref($last_audit_time)) {
         $class->error($client, 'Invalid reply by server, expected last_audit_time dateTime.');
     }
-    $client->log('debug', __PACKAGE__ . "::parameters: Got $last_audit_time");
+    $client->log('debug', $class . "::parameters: Got $last_audit_time");
     return $last_audit_time
 }
 
 sub time {
     my($class, $client) = @_;
-    $client->log('debug', __PACKAGE__ . '::time: Asking');
+    $client->log('debug', $class . '::time: Asking');
     my $time = $class->api_call($client, 'Bugzilla.time');
-    $client->log('debug', __PACKAGE__ . "::time: Got $time");
+    $client->log('debug', $class . "::time: Got $time");
     return wantarray ? %$time : $time
 }
 
 sub timezone {
     my($class, $client) = @_;
-    $client->log('debug', __PACKAGE__ . '::timezone: Asking');
+    $client->log('debug', $class . '::timezone: Asking');
     my $result = $class->api_call($client, 'Bugzilla.timezone');
     my $timezone = $result->{'timezone'};
     if (!$timezone || ref($timezone)) {
         $class->error($client, 'Invalid reply by server, expected timezone scalar.');
     }
-    $client->log('debug', __PACKAGE__ . "::time: Got $timezone");
+    $client->log('debug', $class . "::time: Got $timezone");
     return $timezone
 }
 
 sub version {
     my($class, $client) = @_;
-    $client->log('debug', __PACKAGE__ . '::version: Asking');
+    $client->log('debug', $class . '::version: Asking');
     my $result = $class->api_call($client, 'Bugzilla.version');
     my $version = $result->{'version'};
     if (!$version || ref($version)) {
         $class->error($client, 'Invalid reply by server, expected version scalar.');
     }
-    $client->log('debug', __PACKAGE__ . "::version: Got $version");
+    $client->log('debug', $class . "::version: Got $version");
     return $version
 }
 
@@ -95,7 +96,7 @@ BZ::Client::Bugzilla - Information about the Bugzilla server, i.e. the Bugzilla:
 
 =head1 VERSION
 
-version 2.0_9
+version 2.0_11
 
 =head1 SYNOPSIS
 
@@ -121,6 +122,8 @@ This section lists the class methods, which are available in this module.
 
 Returns a hash or hash ref information about the extensions that are currently installed and enabled in this Bugzilla.
 
+=head3 History
+
 Added in Bugzilla 3.2.
 
 As of Bugzilla 3.6, the names of extensions are canonical names that the extensions define themselves. Before 3.6, the names of the extensions depended on the directory they were in on the Bugzilla server.
@@ -150,7 +153,9 @@ The return value looks something like this:
 
  $last_audit_time = BZ::Client::Bugzilla->extensions( $client, \%params );
 
-Gets the latest time of the audit_log table.
+Gets the latest time of the C<audit_log> table.
+
+=head3 History
 
 Added in Bugzilla 4.4.
 
@@ -179,6 +184,8 @@ The maximum of the C<at_time> from the C<audit_log>, as a L<DateTime> object.
 
 Returns a hash or hashref containing the current Bugzilla parameters.
 
+=head3 History
+
 Added in Bugzilla 4.4.
 
 =head3 Parameters
@@ -191,7 +198,7 @@ A logged-out user can only access the C<maintainer> and C<requirelogin> paramete
 
 A logged-in user can access the following parameters (listed alphabetically): C<allowemailchange>, C<attachment_base>, C<commentonchange_resolution>, C<commentonduplicate>, C<cookiepath>, C<defaultopsys>, C<defaultplatform>, C<defaultpriority>, C<defaultseverity>, C<duplicate_or_move_bug_status>, C<emailregexpdesc>, C<emailsuffix>, C<letsubmitterchoosemilestone>, C<letsubmitterchoosepriority>, C<mailfrom>, C<maintainer>, C<maxattachmentsize>, C<maxlocalattachment>, C<musthavemilestoneonaccept>, C<noresolveonopenblockers>, C<password_complexity>, C<rememberlogin>, C<requirelogin>, C<search_allow_no_criteria>, C<urlbase>, C<use_see_also>, C<useclassification>, C<usemenuforusers>, C<useqacontact>, C<usestatuswhiteboard>, C<usetargetmilestone>.
 
-A user in the tweakparams group can access all existing parameters. New parameters can appear or obsolete parameters can disappear depending on the version of Bugzilla and on extensions being installed. The list of parameters returned by this method is not stable and will never be stable.
+A user in the C<tweakparams> group can access all existing parameters. New parameters can appear or obsolete parameters can disappear depending on the version of Bugzilla and on extensions being installed. The list of parameters returned by this method is not stable and will never be stable.
 
 =head2 time
 
@@ -200,6 +207,8 @@ A user in the tweakparams group can access all existing parameters. New paramete
 
 Gets information about what time the Bugzilla server thinks it is, and what timezone it's running in.
 
+=head3 History
+
 Added in Bugzilla 3.4.
 
 Note: As of Bugzilla 3.6, this method returns all data as though the server were in the UTC timezone, instead of returning information in the server's local timezone.
@@ -216,13 +225,13 @@ A hash with the following items:
 
 =item db_time
 
-I<db_time> (dateTime) -  The current time in UTC, according to the Bugzilla database server.
+I<db_time> (L<DateTime>) -  The current time in UTC, according to the Bugzilla database server.
 
 Note that Bugzilla assumes that the database and the webserver are running in the same time zone. However, if the web server and the database server aren't synchronized for some reason, this is the time that you should rely on for doing searches and other input to the WebService.
 
 =item web_time
 
-I<web_time> (dateTime) -  This is the current time in UTC, according to Bugzilla's web server.
+I<web_time> (L<DateTime>) -  This is the current time in UTC, according to Bugzilla's web server.
 
 This might be different by a second from L</db_time> since this comes from a different source. If it's any more different than a second, then there is likely some problem with this Bugzilla instance. In this case you should rely on the L</db_time>, not the L</web_time>.
 
