@@ -1,13 +1,14 @@
 #!/bin/false
 # PODNAME: BZ::Client::Classification
-# ABSTRACT: Client side representation of a Classifications in Bugzilla
+# ABSTRACT: Client side representation of Classifications in Bugzilla
 
 use strict;
 use warnings 'all';
 
 package BZ::Client::Classification;
-$BZ::Client::Classification::VERSION = '2.0_9';
-use parent qw( BZ::Client::API );
+$BZ::Client::Classification::VERSION = '2.0_11'; # TRIAL
+
+$BZ::Client::Classification::VERSION = '2.011';use parent qw( BZ::Client::API );
 
 # See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Classificaton.html
 # These are in order as per the above
@@ -16,7 +17,7 @@ use parent qw( BZ::Client::API );
 
 sub get {
     my($class, $client, $params) = @_;
-    return _returns_array($client, 'Classification.get', $params, 'classifications');
+    return $class->_returns_array($client, 'Classification.get', $params, 'classifications');
 }
 
 
@@ -30,11 +31,11 @@ __END__
 
 =head1 NAME
 
-BZ::Client::Classification - Client side representation of a Classifications in Bugzilla
+BZ::Client::Classification - Client side representation of Classifications in Bugzilla
 
 =head1 VERSION
 
-version 2.0_9
+version 2.0_11
 
 =head1 SYNOPSIS
 
@@ -57,6 +58,8 @@ This section lists the class methods, which are available in this module.
 
 Returns a hash containing information about a set of classifications.
 
+=head3 History
+
 Added in Bugzilla 4.4.
 
 Marked experiemental as of Bugzilla 5.0.
@@ -64,7 +67,7 @@ Marked experiemental as of Bugzilla 5.0.
 =head3 Parameters
 
 In addition to the parameters below, this method also accepts the standard
-L</include_fields> and L</exclude_fields> arguments.
+L<BZ::Client::Bug/include_fields> and L<BZ::Client::Bug/exclude_fields> arguments.
 
 You could get classifications info by supplying their names and/or ids. So,
 this method accepts the following parameters:
