@@ -6,8 +6,9 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Component;
-$BZ::Client::Component::VERSION = '2.0_9';
-use parent qw( BZ::Client::API );
+$BZ::Client::Component::VERSION = '2.0_11'; # TRIAL
+
+$BZ::Client::Component::VERSION = '2.011';use parent qw( BZ::Client::API );
 
 # See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Component.html
 # These are in order as per the above
@@ -16,17 +17,17 @@ use parent qw( BZ::Client::API );
 
 sub create {
     my($class, $client, $params) = @_;
-    return _create($client, 'Component.create', $params);
+    return $class->_create($client, 'Component.create', $params);
 }
 
 sub update {
     my($class, $client, $params) = @_;
-    return _returns_array($client, 'Component.update', $params, 'components');
+    return $class->_returns_array($client, 'Component.update', $params, 'components');
 }
 
 sub delete {
     my($class, $client, $params) = @_;
-    return _returns_array($client, 'Component.delete', $params, 'components');
+    return $class->_returns_array($client, 'Component.delete', $params, 'components');
 }
 
 1;
@@ -43,7 +44,7 @@ BZ::Client::Component - Client side representation of Product Components in Bugz
 
 =head1 VERSION
 
-version 2.0_9
+version 2.0_11
 
 =head1 SYNOPSIS
 
@@ -68,13 +69,15 @@ This section lists the class methods, which are available in this module.
 
 Returns the ID of the newly created Component.
 
+=head3 History
+
 Added in Bugzilla 5.0.
 
 Marked experiemental as of Bugzilla 5.0.
 
 =head3 Parameters
 
-Some params must be set, or an error will be thrown. These params are marked Required.
+Some params must be set, or an error will be thrown. These params are marked "Required".
 
 =over 4
 
@@ -82,7 +85,7 @@ Some params must be set, or an error will be thrown. These params are marked Req
 
 I<name> (string) The name of the new component.
 
-Required.
+B<Required>.
 
 =item product
 
@@ -90,19 +93,19 @@ I<product> (string) The name of the product that the component must be added to.
 product must already exist, and the user have the necessary permissions to edit components
 for it.
 
-Required.
+B<Required>.
 
 =item description
 
 I<description> (string) The description of the new component.
 
-Required.
+B<Required>.
 
 =item default_assignee
 
 I<default_assignee> (string) The login name of the default assignee of the component.
 
-Required.
+B<Required>.
 
 =item default_cc
 
@@ -145,6 +148,8 @@ The name that you specified for the new component already exists in the specifie
 
 This allows you to update one or more components in Bugzilla.
 
+=head3 History
+
 Added in Bugzilla 5.0.
 
 =head3 Parameters
@@ -157,7 +162,7 @@ Other parameters set or update values of the Component
 
 =item ids
 
-I<ids> (array) Numeric ids of the components that you wish to update.
+I<ids> (array) Numeric ID's of the components that you wish to update.
 
 =item names
 
@@ -207,7 +212,7 @@ An array of hashes with the following fields:
 
 =item id
 
-I<id> (int) The id of the component that was updated.
+I<id> (int) The ID of the component that was updated.
 
 =item changes
 
@@ -224,7 +229,7 @@ I<added> (string) The value that this field was changed to.
 
 I<removed> (string) The value that was previously set in this field.
 
-Note that booleans will be represented with the strings '1' and '0'.
+Note that booleans will be represented with the strings C<1> and C<0>.
 
 =back
 
@@ -299,6 +304,8 @@ A default assignee is required for this component.
 
 This allows you to delete one or more components in Bugzilla.
 
+=head3 History
+
 Added in Bugzilla 5.0.
 
 =head3 Parameters
@@ -309,7 +316,7 @@ You must set one or both of these parameters.
 
 =item ids
 
-I<ids> (array) Numeric IDs of the components that you wish to delete.
+I<ids> (array) Numeric ID's of the components that you wish to delete.
 
 =item names
 
