@@ -6,8 +6,9 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Exception;
-$BZ::Client::Exception::VERSION = '2.0_9';
-sub throw {
+$BZ::Client::Exception::VERSION = '2.0_11'; # TRIAL
+
+$BZ::Client::Exception::VERSION = '2.011';sub throw {
     my $class = shift;
     die $class->new(@_)
 }
@@ -48,7 +49,7 @@ BZ::Client::Exception - Exception class thrown by BZ::Client in case of errors.
 
 =head1 VERSION
 
-version 2.0_9
+version 2.0_11
 
 =head1 SYNOPSIS
 
