@@ -6,21 +6,22 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Product;
-$BZ::Client::Product::VERSION = '2.0_9';
-use parent qw( BZ::Client::API );
+$BZ::Client::Product::VERSION = '2.0_11'; # TRIAL
+
+$BZ::Client::Product::VERSION = '2.011';use parent qw( BZ::Client::API );
 
 # See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Product.html
 
 ## functions
 
 sub create {
-    my($class, $client, $params) = @_;
+    my(undef, $client, $params) = @_;
     return _create($client, 'Product.create', $params);
 }
 
 sub update {
     my($class, $client, $params) = @_;
-    return _returns_array($client, 'Product.update', $params, 'components');
+    return $class->_returns_array($client, 'Product.update', $params, 'components');
 }
 
 # convenience function
@@ -36,25 +37,25 @@ sub _get_list {
 
 sub get_selectable_products {
     my($class, $client) = @_;
-    $client->log('debug', __PACKAGE__ . '::get_selectable_products: Asking');
+    $client->log('debug', $class . '::get_selectable_products: Asking');
     my $result = $class->_get_list('Product.get_selectable_products', $client);
-    $client->log('debug', __PACKAGE__ . '::get_selectable_products: Got ' . @$result);
+    $client->log('debug', $class . '::get_selectable_products: Got ' . @$result);
     return wantarray ? @$result : $result
 }
 
 sub get_enterable_products {
     my($class, $client) = @_;
-    $client->log('debug', __PACKAGE__ . '::get_enterable_products: Asking');
+    $client->log('debug', $class . '::get_enterable_products: Asking');
     my $result = $class->_get_list('Product.get_enterable_products', $client);
-    $client->log('debug', __PACKAGE__ . '::get_enterable_products: Got ' . @$result);
+    $client->log('debug', $class . '::get_enterable_products: Got ' . @$result);
     return wantarray ? @$result : $result
 }
 
 sub get_accessible_products {
     my($class, $client) = @_;
-    $client->log('debug', __PACKAGE__ . '::get_accessible_products: Asking');
+    $client->log('debug', $class . '::get_accessible_products: Asking');
     my $result = $class->_get_list('Product.get_accessible_products', $client);
-    $client->log('debug', __PACKAGE__ . '::get_accessible_products: Got ' . @$result);
+    $client->log('debug', $class . '::get_accessible_products: Got ' . @$result);
     return wantarray ? @$result : $result
 }
 
@@ -211,7 +212,7 @@ BZ::Client::Product - Client side representation of a product in Bugzilla
 
 =head1 VERSION
 
-version 2.0_9
+version 2.0_11
 
 =head1 SYNOPSIS
 
@@ -235,6 +236,8 @@ This section lists the class methods, which are available in this module.
 
 This allows you to create a new Product in Bugzilla.
 
+=head3 History
+
 Marked as experimental as of Bugzilla 5.0.
 
 =head3 Parameters
@@ -247,19 +250,19 @@ Some params must be set, or an error will be thrown. These params are noted as R
 
 I<name> (string) The name of this product. Must be globally unique within Bugzilla.
 
-Required.
+B<Required>.
 
 =item description
 
 I<description> (string) A description for this product. Allows some simple HTML.
 
-Required.
+B<Required>.
 
 =item version
 
 I<version> (string) The default version for this product.
 
-Required.
+B<Required>.
 
 =item has_unconfirmed
 
@@ -323,6 +326,8 @@ You must specify a version for this product.
 
 This allows you to update a Group in Bugzilla.
 
+=head3 History
+
 As of Bugzilla 5.0. this is marked as experimental.
 
 Added in Bugzilla 4.4.
@@ -337,7 +342,7 @@ All other values change or set something in the product.
 
 =item ids
 
-I<ids> (array) Numeric ids of the products you wish to update.
+I<ids> (array) Numeric ID's of the products you wish to update.
 
 =item names
 
@@ -372,7 +377,7 @@ An array or arrayref of hashes containing the following:
 
 =item id
 
-I<id> (int) The id of the product that was updated.
+I<id> (int) The ID of the product that was updated.
 
 =item changes
 
@@ -445,9 +450,11 @@ You must define a default milestone.
  @products = BZ::Client::Product->get_selectable_products( $client );
  $products = BZ::Client::Product->get_selectable_products( $client );
 
-Returns a list of the ids of the products the user can search on.
+Returns a list of the ID's of the products the user can search on.
 
-Note: Marked as experimental as of Bugzilla 5.0.
+=head3 History
+
+Marked as experimental as of Bugzilla 5.0.
 
 =head3 Parameters
 
@@ -466,9 +473,11 @@ An array of product ID's
  @products = BZ::Client::Product->get_enterable_products( $client );
  $products = BZ::Client::Product->get_enterable_products( $client );
 
-Returns a list of the ids of the products the user can enter bugs against.
+Returns a list of the ID's of the products the user can enter bugs against.
 
-Note: Marked as experimental as of Bugzilla 5.0.
+=head3 History
+
+Marked as experimental as of Bugzilla 5.0.
 
 =head3 Parameters
 
@@ -487,9 +496,11 @@ An array of product ID's
  @products = BZ::Client::Product->get_selectable_products( $client );
  $products = BZ::Client::Product->get_selectable_products( $client );
 
-Returns a list of the ids of the products the user can search or enter bugs against.
+Returns a list of the ID's of the products the user can search or enter bugs against.
 
-Note: Marked as unstable as of Bugzilla 5.0.
+=head3 History
+
+Marked as unstable as of Bugzilla 5.0.
 
 =head3 Parameters
 
@@ -517,7 +528,7 @@ silently ignored, and no information about that product is returned.
 =head3 Parameters
 
 In addition to the parameters below, this method also accepts the standard
-L<include_fields> and L<exclude_fields> arguments.
+L<BZ::Client::Bug/include_fields> and L<BZ::Client::Bug/exclude_fields> arguments.
 
 Note: You must at least specify one of L</ids> or L</names>.
 
@@ -525,7 +536,7 @@ Note: You must at least specify one of L</ids> or L</names>.
 
 =item ids
 
-I<ids> (array) An array of product ids.
+I<ids> (array) An array of product ID's.
 
 =item names
 
@@ -650,7 +661,7 @@ An array of hashes, where each hash describes a component, and has the following
 
 =item id
 
-I<id> (int) An integer id uniquely identifying the component in this installation only.
+I<id> (int) An integer ID uniquely identifying the component in this installation only.
 
 =item name
 
@@ -730,12 +741,12 @@ flagtype in a given bug/attachment.
 
 =item grant_group
 
-I<grant_group> (int) the group id that is allowed to grant/deny flags of this type. If the
+I<grant_group> (int) the group ID that is allowed to grant/deny flags of this type. If the
 item is not included all users are allowed to grant/deny this flagtype.
 
 =item request_group
 
-I<request_group> (int) the group id that is allowed to request the flag if the flag is of
+I<request_group> (int) the group ID that is allowed to request the flag if the flag is of
 the type requestable. If the item is not included all users are allowed request this flagtype.
 
 =back
