@@ -6,8 +6,9 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC;
-$BZ::Client::XMLRPC::VERSION = '2.0_9';
-use URI;
+$BZ::Client::XMLRPC::VERSION = '2.0_11'; # TRIAL
+
+$BZ::Client::XMLRPC::VERSION = '2.011';use URI;
 use Encode;
 use XML::Writer;
 use HTTP::Tiny;
@@ -55,7 +56,7 @@ sub web_agent {
         if (!defined($wa)) {
             $wa = HTTP::Tiny->new(
                 %$connect,
-                agent => 'BZ::Client::XMLRPC ' . $BZ::Client::XMLRPC::VERSION
+                agent => sprintf('BZ::Client::XMLRPC %s (perl %s; %s)', $BZ::Client::XMLRPC::VERSION, $^V, $^O)
             );
             $self->web_agent($wa);
         }
@@ -317,15 +318,17 @@ sub logDirectory {
 }
 
 package BZ::Client::XMLRPC::int;
-$BZ::Client::XMLRPC::int::VERSION = '2.0_9';
-sub new {
+$BZ::Client::XMLRPC::int::VERSION = '2.0_11'; # TRIAL
+
+$BZ::Client::XMLRPC::int::VERSION = '2.011';sub new {
     my($class, $value) = @_;
     return bless(\$value, (ref($class) || $class))
 }
 
 package BZ::Client::XMLRPC::boolean;
-$BZ::Client::XMLRPC::boolean::VERSION = '2.0_9';
-sub new {
+$BZ::Client::XMLRPC::boolean::VERSION = '2.0_11'; # TRIAL
+
+$BZ::Client::XMLRPC::boolean::VERSION = '2.011';sub new {
     my($class, $value) = @_;
     return bless(\$value, (ref($class) || $class))
 }
@@ -341,8 +344,9 @@ sub FALSE { $false }
 }
 
 package BZ::Client::XMLRPC::double;
-$BZ::Client::XMLRPC::double::VERSION = '2.0_9';
-sub new {
+$BZ::Client::XMLRPC::double::VERSION = '2.0_11'; # TRIAL
+
+$BZ::Client::XMLRPC::double::VERSION = '2.011';sub new {
     my($class, $value) = @_;
     return bless(\$value, (ref($class) || $class))
 }
@@ -361,7 +365,7 @@ BZ::Client::XMLRPC - Performs XML-RPC calls on behalf of the client.
 
 =head1 VERSION
 
-version 2.0_9
+version 2.0_11
 
 =head1 SYNOPSIS
 
