@@ -6,8 +6,9 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC::Array;
-$BZ::Client::XMLRPC::Array::VERSION = '2.0_9';
-use parent qw(BZ::Client::XMLRPC::Handler);
+$BZ::Client::XMLRPC::Array::VERSION = '2.0_11'; # TRIAL
+
+$BZ::Client::XMLRPC::Array::VERSION = '2.011';use parent qw(BZ::Client::XMLRPC::Handler);
 
 sub init {
     my($self,$parser) = @_;
@@ -63,7 +64,7 @@ BZ::Client::XMLRPC::Array - Event handler for parsing a single XML-RPC array.
 
 =head1 VERSION
 
-version 2.0_9
+version 2.0_11
 
 =head1 AUTHORS
 
