@@ -5,8 +5,9 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC::Handler;
-$BZ::Client::XMLRPC::Handler::VERSION = '2.0_9';
-sub new {
+$BZ::Client::XMLRPC::Handler::VERSION = '2.0_11'; # TRIAL
+
+$BZ::Client::XMLRPC::Handler::VERSION = '2.011';sub new {
     my $class = shift;
     my $self = { @_ };
     $self->{'level'} = 0;
@@ -85,7 +86,7 @@ BZ::Client::XMLRPC::Handler - Abstract event handler for parsing an XML-RPC resp
 
 =head1 VERSION
 
-version 2.0_9
+version 2.0_11
 
 =head1 AUTHORS
 
