@@ -6,8 +6,9 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC::Parser;
-$BZ::Client::XMLRPC::Parser::VERSION = '2.0_9';
-use BZ::Client::XMLRPC::Response;
+$BZ::Client::XMLRPC::Parser::VERSION = '2.0_11'; # TRIAL
+
+$BZ::Client::XMLRPC::Parser::VERSION = '2.011';use BZ::Client::XMLRPC::Response;
 use BZ::Client::Exception;
 use XML::Parser ();
 
@@ -28,19 +29,19 @@ sub parse {
         $self->{'result'} = $handler->result();
     });
     my $start = sub {
-        my($expat, $name, @args) = @_;
+        my(undef, $name) = @_;
         my $current = $self->{'current'};
         $self->error('Illegal state, no more handlers available on stack.') unless $current;
         $current->start($name);
     };
     my $end = sub {
-        my($expat, $name) = @_;
+        my(undef, $name) = @_;
         my $current = $self->{'current'};
         $self->error('Illegal state, no more handlers available on stack.') unless $current;
         $current->end($name);
     };
     my $chars = sub {
-        my($expat, $text) = @_;
+        my(undef, $text) = @_;
         my $current = $self->{'current'};
         $self->error('Illegal state, no more handlers available on stack.') unless $current;
         $current->characters($text);
@@ -105,7 +106,7 @@ BZ::Client::XMLRPC::Parser - A parser for an XML-RPC response.
 
 =head1 VERSION
 
-version 2.0_9
+version 2.0_11
 
 =head1 AUTHORS
 
