@@ -6,8 +6,9 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC::Response;
-$BZ::Client::XMLRPC::Response::VERSION = '2.0_9';
-use parent qw( BZ::Client::XMLRPC::Handler );
+$BZ::Client::XMLRPC::Response::VERSION = '2.0_11'; # TRIAL
+
+$BZ::Client::XMLRPC::Response::VERSION = '2.011';use parent qw( BZ::Client::XMLRPC::Handler );
 use BZ::Client::XMLRPC::Value;
 use BZ::Client::Exception;
 
@@ -103,7 +104,7 @@ BZ::Client::XMLRPC::Response - Event handler for parsing an XML-RPC response.
 
 =head1 VERSION
 
-version 2.0_9
+version 2.0_11
 
 =head1 AUTHORS
 
