@@ -6,8 +6,9 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC::Struct;
-$BZ::Client::XMLRPC::Struct::VERSION = '2.0_9';
-use parent qw(BZ::Client::XMLRPC::Handler );
+$BZ::Client::XMLRPC::Struct::VERSION = '2.0_11'; # TRIAL
+
+$BZ::Client::XMLRPC::Struct::VERSION = '2.011';use parent qw(BZ::Client::XMLRPC::Handler );
 
 sub init {
     my ($self, $parser) = @_;
@@ -87,7 +88,7 @@ BZ::Client::XMLRPC::Struct - Event handler for parsing a single XML-RPC struct.
 
 =head1 VERSION
 
-version 2.0_9
+version 2.0_11
 
 =head1 AUTHORS
 
