@@ -6,8 +6,9 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC::Value;
-$BZ::Client::XMLRPC::Value::VERSION = '2.0_9';
-use parent qw( BZ::Client::XMLRPC::Handler );
+$BZ::Client::XMLRPC::Value::VERSION = '2.0_11'; # TRIAL
+
+$BZ::Client::XMLRPC::Value::VERSION = '2.011';use parent qw( BZ::Client::XMLRPC::Handler );
 use BZ::Client::XMLRPC::Struct;
 use BZ::Client::XMLRPC::Array;
 use DateTime::Format::ISO8601 ();
@@ -136,7 +137,7 @@ BZ::Client::XMLRPC::Value - Event handler for parsing a single XML-RPC value.
 
 =head1 VERSION
 
-version 2.0_9
+version 2.0_11
 
 =head1 AUTHORS
 
